Version enum

UUID version.

Only Version.v4, Version.v7, and Version.v8 are generated; when parsing an arbitrary UUID, an out-of-range version yields Version.unknown.

Inheritance
Available extensions

Values

v4 → const Version
v7 → const Version
v8 → const Version
unknown → const Version

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
The numeric version value.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromNibble(int nibble) Version
Constructs from the version nibble (high 4 bits of byte 6).

Constants

values → const List<Version>
A constant List of the values in this enum, in order of their declaration.